@@ -22,6 +22,7 @@
 
 #include <Lum/Def/Menu.h>
 
+#include <Lum/Application.h>
 #include <Lum/Button.h>
 #include <Lum/Dialog.h>
 #include <Lum/Panel.h>
@@ -31,8 +32,6 @@
 
 #include <Lum/Model/Action.h>
 
-#include <Lum/OS/Main.h>
-
 #include "config.h"
 #include "Control.h"
 
@@ -106,10 +105,10 @@ public:
   }
 };
 
-class Main : public Lum::OS::MainDialog<MainDialog>
+class Main : public Lum::GUIApplication<MainDialog>
 {
 public:
-  Main()
+  bool Initialize()
   {
     info.SetProgram(Lum::Base::StringToWString(PACKAGE_NAME));
     info.SetVersion(Lum::Base::StringToWString(PACKAGE_VERSION));
@@ -118,16 +117,8 @@ public:
     info.SetContact(L"Tim Teulings <tim@teulings.org>");
     info.SetCopyright(L"(c) 2007, Tim Teulings");
     info.SetLicense(L"GNU Public License");
-  }
-
-  bool Prepare()
-  {
-    return Lum::OS::MainDialog<MainDialog>::Prepare();
-  }
-
-  void Cleanup()
-  {
-    Lum::OS::MainDialog<MainDialog>::Cleanup();
+    
+    return Lum::GUIApplication<MainDialog>::Initialize();
   }
 };
 
